"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

const injectString = (pool, value) => `${pool.escape(value)}`;

const injectNumber = (pool, value) => `${+value}`;

const createQuery = (pool, filter) => {
  const {
    escapeId
  } = pool;
  const {
    eventTypes,
    aggregateIds
  } = filter;
  const queryConditions = [];

  if (eventTypes != null) {
    queryConditions.push(`${escapeId('type')} IN (${eventTypes.map(injectString.bind(null, pool)).join(', ')})`);
  }

  if (aggregateIds != null) {
    queryConditions.push(`${escapeId('aggregateId')} IN (${aggregateIds.map(injectString.bind(null, pool)).join(', ')})`);
  }

  if ((0, _eventstoreBase.isTimestampFilter)(filter)) {
    const {
      startTime,
      finishTime
    } = filter;

    if (startTime != null) {
      queryConditions.push(`${escapeId('timestamp')} > ${injectNumber(pool, startTime)}`);
    }

    if (finishTime != null) {
      queryConditions.push(`${escapeId('timestamp')} < ${injectNumber(pool, finishTime)}`);
    }
  }

  return queryConditions.length > 0 ? `WHERE ${queryConditions.join(' AND ')}` : '';
};

var _default = createQuery;
exports.default = _default;
//# sourceMappingURL=create-query.js.map