"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

var _resourceErrors = require("./resource-errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropEvents = async ({
  database,
  databaseFile,
  eventsTableName,
  snapshotsTableName,
  subscribersTableName,
  escapeId
}) => {
  const log = (0, _getLog.default)('dropEvents');
  log.debug(`dropping events`);
  const incrementalImportTableAsId = escapeId(`${eventsTableName}-incremental-import`);
  const statements = [`DROP TABLE IF EXISTS ${escapeId(`${eventsTableName}-freeze`)}`, `DROP TABLE ${escapeId(eventsTableName)}`, `DROP TABLE ${escapeId(snapshotsTableName)}`, `DROP TABLE IF EXISTS ${incrementalImportTableAsId}`, `DROP TABLE ${escapeId(subscribersTableName)}`];
  const errors = await (0, _executeSequence.default)(database, statements, log, error => {
    if ((0, _resourceErrors.isNotExistError)(error.message)) {
      return new _eventstoreBase.EventstoreResourceNotExistError(`sqlite adapter for database "${databaseFile}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping events`);
  return errors;
};

var _default = dropEvents;
exports.default = _default;
//# sourceMappingURL=drop-events.js.map