"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _constants = require("./constants");

var _getLog = _interopRequireDefault(require("./get-log"));

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

var _resourceErrors = require("./resource-errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initEvents = async ({
  database,
  databaseFile,
  eventsTableName,
  snapshotsTableName,
  subscribersTableName,
  escapeId
}) => {
  const log = (0, _getLog.default)('initEvents');
  log.debug('initializing events tables');
  const statements = [`CREATE TABLE ${escapeId(eventsTableName)}(
      ${escapeId('threadId')} BIGINT NOT NULL,
      ${escapeId('threadCounter')} BIGINT NOT NULL,
      ${escapeId('timestamp')} BIGINT NOT NULL,
      ${escapeId('aggregateId')} ${_constants.AGGREGATE_ID_SQL_TYPE} NOT NULL,
      ${escapeId('aggregateVersion')} BIGINT NOT NULL,
      ${escapeId('type')} VARCHAR(700) NOT NULL,
      ${escapeId('payload')} JSON NULL,
      PRIMARY KEY(${escapeId('threadId')}, ${escapeId('threadCounter')}),
      UNIQUE(${escapeId('aggregateId')}, ${escapeId('aggregateVersion')})
    )`, `CREATE INDEX ${escapeId('aggregateIdAndVersion-idx')} ON ${escapeId(eventsTableName)}(
      ${escapeId('aggregateId')}, ${escapeId('aggregateVersion')}
    )`, `CREATE INDEX ${escapeId('aggregateId-idx')} ON ${escapeId(eventsTableName)}(
      ${escapeId('aggregateId')}
    )`, `CREATE INDEX ${escapeId('aggregateVersion-idx')} ON ${escapeId(eventsTableName)}(
      ${escapeId('aggregateVersion')}
    )`, `CREATE INDEX ${escapeId('type-idx')} ON ${escapeId(eventsTableName)}(
      ${escapeId('type')}
    )`, `CREATE INDEX ${escapeId('timestamp-idx')} ON ${escapeId(eventsTableName)}(
      ${escapeId('timestamp')}
    )`, `CREATE TABLE ${escapeId(snapshotsTableName)} (
      ${escapeId('snapshotKey')} TEXT,
      ${escapeId('content')} TEXT,
      PRIMARY KEY(${escapeId('snapshotKey')})
    )`, `CREATE TABLE ${escapeId(subscribersTableName)} (
      ${escapeId('applicationName')} VARCHAR(700) NOT NULL,
      ${escapeId('eventSubscriber')} VARCHAR(700) NOT NULL,
      ${escapeId('destination')} JSON NOT NULL,
      ${escapeId('status')} JSON NOT NULL,
      PRIMARY KEY(${escapeId('applicationName')}, ${escapeId('eventSubscriber')})
    )`];
  const errors = await (0, _executeSequence.default)(database, statements, log, error => {
    if ((0, _resourceErrors.isAlreadyExistsError)(error.message)) {
      return new _eventstoreBase.EventstoreResourceAlreadyExistError(`duplicate initialization of the sqlite adapter with the same event database "${databaseFile}" and table "${eventsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing events tables');
  return errors;
};

var _default = initEvents;
exports.default = _default;
//# sourceMappingURL=init-events.js.map