"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

var _eventstoreBase = require("@resolve-js/eventstore-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setSecret = async ({
  database,
  eventsTableName,
  secretsTableName,
  escape,
  escapeId
}, selector, secret) => {
  const log = (0, _getLog.default)('secretsManager:setSecret');
  log.debug(`setting secret value within database`);
  log.verbose(`selector: ${selector}`);
  log.verbose(`database: ${database}`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const tableId = escapeId(secretsTableName);
  const freezeTableNameAsString = escape(`${eventsTableName}-freeze`);

  try {
    log.debug(`executing SQL query`);
    await database.exec(`BEGIN IMMEDIATE;

      SELECT ABS("CTE"."EventStoreIsFrozen") FROM (
        SELECT 0 AS "EventStoreIsFrozen"
      UNION ALL
        SELECT -9223372036854775808 AS "EventStoreIsFrozen"
        FROM "sqlite_master"
        WHERE "type" = 'table' AND 
        "name" = ${freezeTableNameAsString}
      ) CTE;
      INSERT INTO ${tableId}(
        "idx", 
        "id", 
        "secret"
        ) VALUES (
         COALESCE(
          (SELECT MAX("idx") FROM ${tableId}) + 1,
          0
         ),
         ${escape(selector)},
         ${escape(secret)}
       );
       
       COMMIT;`);
    log.debug(`query executed successfully`);
  } catch (error) {
    try {
      await database.exec('ROLLBACK;');
    } catch (e) {}

    const errorMessage = error != null && error.message != null ? error.message : '';

    if (errorMessage === 'SQLITE_ERROR: integer overflow') {
      throw new _eventstoreBase.EventstoreFrozenError();
    } else {
      log.error(error.message);
      log.verbose(error.stack);
      throw error;
    }
  }
};

var _default = setSecret;
exports.default = _default;
//# sourceMappingURL=set-secret.js.map