import type { open, Database } from 'sqlite';
import type { AdapterPoolConnectedProps, AdapterPoolConnected, AdapterPoolPossiblyUnconnected } from '@resolve-js/eventstore-base';
import { UnbrandProps, iots as t, iotsTypes } from '@resolve-js/eventstore-base';
export declare type SqliteOpen = typeof open;
export declare type MemoryStore = {
    name: string;
    drop: () => void;
};
export declare type SqliteAdapterPoolConnectedProps = AdapterPoolConnectedProps & {
    database: Database;
    databaseFile: string;
    eventsTableName: string;
    snapshotsTableName: string;
    secretsTableName: string;
    subscribersTableName: string;
    escapeId: (source: string) => string;
    escape: (source: string) => string;
    memoryStore?: MemoryStore;
};
export declare const SqliteAdapterConfigSchema: t.IntersectionC<[t.PartialC<{
    snapshotBucketSize: t.BrandC<t.NumberC, t.IntBrand>;
}>, t.PartialC<{
    databaseFile: iotsTypes.NonEmptyStringC;
    secretsTableName: iotsTypes.NonEmptyStringC;
    eventsTableName: iotsTypes.NonEmptyStringC;
    snapshotsTableName: iotsTypes.NonEmptyStringC;
    subscribersTableName: iotsTypes.NonEmptyStringC;
}>]>;
declare type SqliteAdapterConfigChecked = t.TypeOf<typeof SqliteAdapterConfigSchema>;
export declare type SqliteAdapterConfig = UnbrandProps<SqliteAdapterConfigChecked>;
export declare type AdapterPool = AdapterPoolConnected<SqliteAdapterPoolConnectedProps>;
export declare type AdapterPoolPrimal = AdapterPoolPossiblyUnconnected<SqliteAdapterPoolConnectedProps>;
export declare type ConnectionDependencies = {
    sqlite: {
        open: SqliteOpen;
    };
    tmp: any;
    os: any;
    fs: any;
};
export {};
